interface EventSourceFactory {
    new (path: string): EventSource;
}
export declare const injectEvents: (eventSource: EventSourceFactory) => {
    new (options: Partial<Options> & {
        name: string;
        path: string;
    }): {
        /**
         * Registered listeners
         */
        listeners: Set<Listener>;
        /**
         * EventSource `onmessage` handler
         */
        onmessage: (payload: MessageEvent) => Promise<void>;
        /**
         * EventSource `onopen` handler
         */
        onopen: () => void;
        options: Partial<Options> & {
            name: string;
            path: string;
        };
        /**
         * EventSource `addMessageListener` handler
         */
        addListener(listener: Listener): this;
        onerror: (this: EventSource, ev: Event) => any;
        readonly readyState: number;
        readonly url: string;
        readonly withCredentials: boolean;
        close(): void;
        readonly CONNECTING: 0;
        readonly OPEN: 1;
        readonly CLOSED: 2;
        addEventListener<K extends keyof EventSourceEventMap>(type: K, listener: (this: EventSource, ev: EventSourceEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;
        addEventListener(type: string, listener: (this: EventSource, event: MessageEvent<any>) => any, options?: boolean | AddEventListenerOptions): void;
        addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;
        removeEventListener<K_1 extends keyof EventSourceEventMap>(type: K_1, listener: (this: EventSource, ev: EventSourceEventMap[K_1]) => any, options?: boolean | EventListenerOptions): void;
        removeEventListener(type: string, listener: (this: EventSource, event: MessageEvent<any>) => any, options?: boolean | EventListenerOptions): void;
        removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;
        dispatchEvent(event: Event): boolean;
    };
    /**
     * Singleton constructor
     *
     */
    make(options: Partial<Options> & {
        name: string;
        path: string;
    }): {
        /**
         * Registered listeners
         */
        listeners: Set<Listener>;
        /**
         * EventSource `onmessage` handler
         */
        onmessage: (payload: MessageEvent) => Promise<void>;
        /**
         * EventSource `onopen` handler
         */
        onopen: () => void;
        options: Partial<Options> & {
            name: string;
            path: string;
        };
        /**
         * EventSource `addMessageListener` handler
         */
        addListener(listener: Listener): this;
        onerror: (this: EventSource, ev: Event) => any;
        readonly readyState: number;
        readonly url: string;
        readonly withCredentials: boolean;
        close(): void;
        readonly CONNECTING: 0;
        readonly OPEN: 1;
        readonly CLOSED: 2;
        addEventListener<K extends keyof EventSourceEventMap>(type: K, listener: (this: EventSource, ev: EventSourceEventMap[K]) => any, options?: boolean | AddEventListenerOptions): void;
        addEventListener(type: string, listener: (this: EventSource, event: MessageEvent<any>) => any, options?: boolean | AddEventListenerOptions): void;
        addEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | AddEventListenerOptions): void;
        removeEventListener<K_1 extends keyof EventSourceEventMap>(type: K_1, listener: (this: EventSource, ev: EventSourceEventMap[K_1]) => any, options?: boolean | EventListenerOptions): void;
        removeEventListener(type: string, listener: (this: EventSource, event: MessageEvent<any>) => any, options?: boolean | EventListenerOptions): void;
        removeEventListener(type: string, listener: EventListenerOrEventListenerObject, options?: boolean | EventListenerOptions): void;
        dispatchEvent(event: Event): boolean;
    };
};
export {};
